About
=====

Authors
-------

*articubench* was mainly developed by
`Konstantin Sering <https://github.com/derNarr>`_ and
`Paul Schmidt-Barbo <https://github.com/paulovic96>`_,
For the full list of contributors have a look at `Github's Contributor summary
<https://github.com/quantling/paule/contributors>`_.

Currently, it is maintained by `Konstantin Sering <https://github.com/derNarr>`_
and `Paul Schmidt-Barbo <https://github.com/paulovic96>`_.


Contact
-------

In case you want to contact the project maintainers, please send an email to

      konstantin [dot] sering [at] uni [minus] tuebingen [dot de


Citation
--------
TODO see pyndl.


Funding
-------
*articubench* was partially funded by an ERC Advanced Grant (no. 742545)..


Acknowledgements
----------------
TODO

